@@ -7,10 +7,11 @@ from pkginfo.distribution import Distribution
 
 class Develop(Distribution):
 
-    def __init__(self, path):
+    def __init__(self, path, metadata_version=None):
         self.path = os.path.abspath(
                         os.path.normpath(
                             os.path.expanduser(path)))
+        self.metadata_version = metadata_version
         self.extractMetadata()
 
     def read(self):
@@ -21,5 +22,6 @@ class Develop(Distribution):
             if os.path.isdir(candidate):
                 path = os.path.join(candidate, 'PKG-INFO')
                 if os.path.exists(path):
-                    return open(path).read()
+                    with open(path) as f:
+                        return f.read()
         warnings.warn('No PKG-INFO found for path: %s' % self.path)
