@@ -22,7 +22,7 @@ class SDist(Distribution):
             names = archive.namelist()
             def read_file(name):
                 return archive.read(name)
-        elif fqn.endswith(('.bz2', '.gz')):
+        elif fqn.endswith('gz') or fqn.endswith('bz2'):
             archive = tarfile.TarFile.open(fqn)
             names = archive.getnames()
             def read_file(name):
@@ -30,12 +30,15 @@ class SDist(Distribution):
         else:
             raise ValueError('Not a known archive format: %s' % fqn)
 
-        tuples = [x.split('/') for x in names if 'PKG-INFO' in x]
-        schwarz = sorted([(len(x), x) for x in tuples])
-        for path in [x[1] for x in schwarz]:
-            candidate = '/'.join(path)
-            data = read_file(candidate)
-            if 'Metadata-Version' in data:
-                return data
+        try:
+            tuples = [x.split('/') for x in names if 'PKG-INFO' in x]
+            schwarz = sorted([(len(x), x) for x in tuples])
+            for path in [x[1] for x in schwarz]:
+                candidate = '/'.join(path)
+                data = read_file(candidate)
+                if b'Metadata-Version' in data:
+                    return data
+        finally:
+            archive.close()
 
         raise ValueError('No PKG-INFO in archive: %s' % fqn)
